# -*- coding: utf-8 -*-
# @Project: 芒果测试平台
# @Description: 
# @Time   : 2025-07-24 11:02
# @Author : 毛鹏
from .mango import *
from .model_crud import *

__all__ = [
    'Mango',
    'test',
    'get',
    'post',
    'put',
    'delete',
    'inside_post',
    'inside_put',
    'inside_delete',
]
